@@ -205,6 +205,7 @@ enum {
 	FUNCTION_ID_NORM = 1138,
 	FUNCTION_ID_VERTCAT = 1139,
 	FUNCTION_ID_HORZCAT = 1140,
+	FUNCTION_ID_KRONECKER_PRODUCT = 1141,
 	FUNCTION_ID_SQRT = 1200,
 	FUNCTION_ID_CBRT = 1201,
 	FUNCTION_ID_ROOT = 1202,
@@ -274,11 +275,18 @@ enum {
 	FUNCTION_ID_REM = 1734,
 	FUNCTION_ID_MOD = 1735,
 	FUNCTION_ID_PARALLEL = 1736,
+	FUNCTION_ID_POWER_MOD = 1737,
 	FUNCTION_ID_BERNOULLI = 1740,
 	FUNCTION_ID_TOTIENT = 1745,
 	FUNCTION_ID_RE = 1750,
 	FUNCTION_ID_IM = 1751,
 	FUNCTION_ID_ARG = 1752,
+	FUNCTION_ID_PRIME_COUNT = 1760,
+	FUNCTION_ID_NTH_PRIME = 1761,
+	FUNCTION_ID_PREV_PRIME = 1762,
+	FUNCTION_ID_NEXT_PRIME = 1763,
+	FUNCTION_ID_PRIMES = 1764,
+	FUNCTION_ID_IS_PRIME = 1765,
 	FUNCTION_ID_DIFFERENTIATE = 1800,
 	FUNCTION_ID_LIMIT = 1810,
 	FUNCTION_ID_INTEGRATE = 1820,
@@ -298,6 +306,7 @@ enum {
 	FUNCTION_ID_BASE = 1904,
 	FUNCTION_ID_ROMAN = 1905,
 	FUNCTION_ID_BIJECTIVE = 1906,
+	FUNCTION_ID_BINARY_DECIMAL = 1907,
 	FUNCTION_ID_IEEE754_FLOAT = 1910,
 	FUNCTION_ID_IEEE754_FLOAT_BITS = 1911,
 	FUNCTION_ID_IEEE754_FLOAT_COMPONENTS = 1912,
@@ -353,6 +362,10 @@ enum {
 	FUNCTION_ID_NEXT_LUNAR_PHASE = 2351,
 	FUNCTION_ID_INTERVAL = 2400,
 	FUNCTION_ID_UNCERTAINTY = 2401,
+	FUNCTION_ID_LOWER_END_POINT = 2402,
+	FUNCTION_ID_UPPER_END_POINT = 2403,
+	FUNCTION_ID_MID_POINT = 2404,
+	FUNCTION_ID_GET_UNCERTAINTY = 2404,
 	FUNCTION_ID_ASCII = 2500,
 	FUNCTION_ID_CHAR = 2501,
 	FUNCTION_ID_LENGTH = 2502,
@@ -417,6 +430,7 @@ DECLARE_BUILTIN_FUNCTION(EntrywiseMultiplicationFunction, FUNCTION_ID_ENTRYWISE_
 DECLARE_BUILTIN_FUNCTION(EntrywiseDivisionFunction, FUNCTION_ID_ENTRYWISE_DIVISION)
 DECLARE_BUILTIN_FUNCTION(EntrywisePowerFunction, FUNCTION_ID_ENTRYWISE_POWER)
 DECLARE_BUILTIN_FUNCTION(NormFunction, FUNCTION_ID_NORM)
+DECLARE_BUILTIN_FUNCTION_MT(KroneckerProductFunction, FUNCTION_ID_KRONECKER_PRODUCT)
 
 DECLARE_BUILTIN_FUNCTION_R(SqrtFunction, FUNCTION_ID_SQRT)
 DECLARE_BUILTIN_FUNCTION(CbrtFunction, FUNCTION_ID_CBRT)
@@ -499,6 +513,12 @@ DECLARE_BUILTIN_FUNCTION_R(AbsFunction, FUNCTION_ID_ABS)
 DECLARE_BUILTIN_FUNCTION_MT(GcdFunction, FUNCTION_ID_GCD)
 DECLARE_BUILTIN_FUNCTION_MT(LcmFunction, FUNCTION_ID_LCM)
 DECLARE_BUILTIN_FUNCTION(DivisorsFunction, FUNCTION_ID_DIVISORS)
+DECLARE_BUILTIN_FUNCTION_MT(PrimeCountFunction, FUNCTION_ID_PRIME_COUNT)
+DECLARE_BUILTIN_FUNCTION_MT(IsPrimeFunction, FUNCTION_ID_IS_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(NthPrimeFunction, FUNCTION_ID_NTH_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(PrimesFunction, FUNCTION_ID_PRIMES)
+DECLARE_BUILTIN_FUNCTION_MT(PrevPrimeFunction, FUNCTION_ID_PREV_PRIME)
+DECLARE_BUILTIN_FUNCTION_MT(NextPrimeFunction, FUNCTION_ID_NEXT_PRIME)
 DECLARE_BUILTIN_FUNCTION_R(SignumFunction, FUNCTION_ID_SIGNUM)
 DECLARE_BUILTIN_FUNCTION_R(RoundFunction, FUNCTION_ID_ROUND)
 DECLARE_BUILTIN_FUNCTION_R(FloorFunction, FUNCTION_ID_FLOOR)
@@ -510,9 +530,14 @@ DECLARE_BUILTIN_FUNCTION_MT(IntFunction, FUNCTION_ID_INT)
 DECLARE_BUILTIN_FUNCTION_MT(FracFunction, FUNCTION_ID_FRAC)
 DECLARE_BUILTIN_FUNCTION_MT(RemFunction, FUNCTION_ID_REM)
 DECLARE_BUILTIN_FUNCTION_MT(ModFunction, FUNCTION_ID_MOD)
+DECLARE_BUILTIN_FUNCTION_MT(PowerModFunction, FUNCTION_ID_POWER_MOD)
 DECLARE_BUILTIN_FUNCTION_MT(BernoulliFunction, FUNCTION_ID_BERNOULLI)
 DECLARE_BUILTIN_FUNCTION_MT(TotientFunction, FUNCTION_ID_TOTIENT)
 DECLARE_BUILTIN_FUNCTION(ParallelFunction, FUNCTION_ID_PARALLEL)
+DECLARE_BUILTIN_FUNCTION_MT(LowerEndPointFunction, FUNCTION_ID_LOWER_END_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(UpperEndPointFunction, FUNCTION_ID_UPPER_END_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(MidPointFunction, FUNCTION_ID_MID_POINT)
+DECLARE_BUILTIN_FUNCTION_MT(GetUncertaintyFunction, FUNCTION_ID_GET_UNCERTAINTY)
 
 DECLARE_BUILTIN_FUNCTION(BinFunction, FUNCTION_ID_BIN)
 DECLARE_BUILTIN_FUNCTION(OctFunction, FUNCTION_ID_OCT)
@@ -521,6 +546,7 @@ DECLARE_BUILTIN_FUNCTION(HexFunction, FUNCTION_ID_HEX)
 DECLARE_BUILTIN_FUNCTION(BaseFunction, FUNCTION_ID_BASE)
 DECLARE_BUILTIN_FUNCTION(RomanFunction, FUNCTION_ID_ROMAN)
 DECLARE_BUILTIN_FUNCTION(BijectiveFunction, FUNCTION_ID_BIJECTIVE)
+DECLARE_BUILTIN_FUNCTION(BinaryDecimalFunction, FUNCTION_ID_BINARY_DECIMAL)
 
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatFunction, FUNCTION_ID_IEEE754_FLOAT)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatBitsFunction, FUNCTION_ID_IEEE754_FLOAT_BITS)
